@@ -1263,6 +1263,7 @@ class Nmltype:
     :ivar collection:
     :ivar sets:
     :ivar playlists:
+    :ivar indexing:
     :ivar sorting_order:
     :ivar version:
     """
@@ -1309,6 +1310,14 @@ class Nmltype:
             required=True
         )
     )
+    indexing: Optional[str] = field(
+        default=None,
+        metadata=dict(
+            name="INDEXING",
+            type="Element",
+            required=True
+        )
+    )
     sorting_order: List[SortingOrdertype] = field(
         default_factory=list,
         metadata=dict(
